LIBRARY IEEE; 
USE IEEE.STD_LOGIC_1164.all; 
USE IEEE.numeric_std.all; 

-- VGA Video Sync generation 


entity frame is
   port(clk_50M: in std_logic;
        vga_r: out std_logic_vector(3 downto 0);
        vga_g: out std_logic_vector(3 downto 0);
        vga_b: out std_logic_vector(3 downto 0);
        vga_hsync: out std_logic;
        vga_vsync: out std_logic);
end entity frame;

architecture a of frame is
   component VGA_SYNC IS 
      PORT(clock_25Mhz, red, green, blue: IN STD_LOGIC; 
           red_out, green_out, blue_out, horiz_sync_out, vert_sync_out: OUT STD_LOGIC;
           pixel_row, pixel_column : OUT STD_LOGIC_VECTOR(9 DOWNTO 0)); 
   END component;

   COMPONENT clock_divider
   PORT(CLKIN_IN : IN std_logic;        
             CLKDV_OUT : OUT std_logic;
             CLKIN_IBUFG_OUT : OUT std_logic;
             CLK0_OUT : OUT std_logic;
             LOCKED_OUT : OUT std_logic);
END COMPONENT;

signal pixel_row, pixel_column: std_logic_vector(9 downto 0);
signal red,green, blue: std_logic;
signal frame: std_logic;
signal clk_25m: std_logic;
signal red_out,green_out,blue_out: std_logic;
begin

framegen:VGA_SYNC
      PORT MAP(clock_25Mhz => clk_25m,
                 		red => red,
                       green => green,
 							  blue => blue, 
                       red_out => red_out,
	                    green_out => green_out,
                       blue_out => blue_out, 
							  horiz_sync_out => vga_hsync,
							  vert_sync_out => vga_vsync,
                       pixel_row => pixel_row, 
							  pixel_column => pixel_column); 

clkdiv: clock_divider
   PORT MAP(
            CLKIN_IN => clk_50m,        
            CLKDV_OUT => clk_25m);
				
vga_r <= (others => red_out);
vga_g <= (others => green_out);
vga_b <= (others => blue_out);

frame <= '1' when
   pixel_row=std_logic_vector(to_unsigned(0,10)) or
   pixel_column=std_logic_vector(to_unsigned(0,10)) or
   pixel_row=std_logic_vector(to_unsigned(479,10)) or
   pixel_column=std_logic_vector(to_unsigned(639,10)) or
   pixel_row=std_logic_vector(to_unsigned(239,10)) or
   pixel_column=std_logic_vector(to_unsigned(319,10)) 
	else '0';
							
red <= frame;
green <= frame;
blue <= frame;
					
end architecture a;


